@@ -43,6 +43,7 @@ use Mouse            0.61;
 use Params::Util         1.00 ();
 use FBP::Project              ();
 use FBP::Dialog               ();
+use FBP::AnimationCtrl        ();
 use FBP::BitmapButton         ();
 use FBP::BoxSizer             ();
 use FBP::Button               ();
@@ -60,6 +61,8 @@ use FBP::FontPickerCtrl       ();
 use FBP::FormPanel            ();
 use FBP::Frame                ();
 use FBP::Gauge                ();
+use FBP::GridBagSizer         ();
+use FBP::GridBagSizerItem     ();
 use FBP::GridSizer            ();
 use FBP::HtmlWindow           ();
 use FBP::HyperLink            ();
@@ -71,8 +74,11 @@ use FBP::Menu                 ();
 use FBP::MenuBar              ();
 use FBP::MenuItem             ();
 use FBP::MenuSeparator        ();
+use FBP::Notebook             ();
+use FBP::NotebookPage         ();
 use FBP::Panel                ();
 use FBP::RadioBox             ();
+use FBP::RadioButton          ();
 use FBP::ScrolledWindow       ();
 use FBP::SearchCtrl           ();
 use FBP::SizerItem            ();
@@ -92,8 +98,9 @@ use FBP::ToggleButton         ();
 use FBP::Tool                 ();
 use FBP::ToolBar              ();
 use FBP::ToolSeparator        ();
+use FBP::TreeCtrl             ();
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Object';
 with    'FBP::Children';
