@@ -1,9 +1,8 @@
 package FBP::BitmapButton;
 
 use Mouse;
-use FBP::Control;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Control';
 
@@ -42,4 +41,7 @@ has OnButtonClick => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
