@@ -2,7 +2,7 @@ package FBP::BoxSizer;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Sizer';
 
@@ -12,4 +12,7 @@ has orient => (
 	required => 1,
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
