@@ -2,7 +2,7 @@ package FBP::CalendarCtrl;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Control';
 
@@ -41,4 +41,7 @@ has OnCalendarWeekDayClicked => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
