@@ -2,7 +2,7 @@ package FBP::Choice;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::ControlWithItems';
 
@@ -17,4 +17,7 @@ has OnChoice => (
 	isa      => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
