@@ -2,7 +2,7 @@ package FBP::Control;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Window';
 
@@ -11,4 +11,7 @@ has default => (
 	isa => 'Bool',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
