@@ -2,7 +2,7 @@ package FBP::ControlWithItems;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Control';
 
@@ -21,4 +21,7 @@ sub items {
 	return @choices;
 }
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
