@@ -2,7 +2,7 @@ package FBP::CustomControl;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Window';
 
@@ -31,6 +31,8 @@ has settings => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
 
 
 
