@@ -2,7 +2,7 @@ package FBP::Gauge;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Control';
 
@@ -28,4 +28,7 @@ has style => (
 	isa      => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
