@@ -2,7 +2,7 @@ package FBP::GridSizer;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Sizer';
 
@@ -30,4 +30,7 @@ has hgap => (
 	required => 1,
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
