@@ -2,7 +2,7 @@ package FBP::HtmlWindow;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Window';
 
@@ -26,4 +26,7 @@ has OnHtmlLinkClicked => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
