@@ -2,7 +2,7 @@ package FBP::ListCtrl;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Control';
 
@@ -111,4 +111,7 @@ has OnListCacheHint => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
