@@ -2,7 +2,7 @@ package FBP::ListbookPage;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Object';
 with    'FBP::Children';
@@ -17,4 +17,7 @@ has select => (
 	isa => 'Int',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
