@@ -2,18 +2,11 @@ package FBP::Menu;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Object';
 with    'FBP::Children';
 
-
-
-
-
-######################################################################
-# Properties
-
 has name => (
 	is  => 'ro',
 	isa => 'Str',
@@ -24,4 +17,7 @@ has label => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
