@@ -2,17 +2,10 @@ package FBP::MenuBar;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Window';
 
-
-
-
-
-######################################################################
-# Properties
-
 has label => (
 	is       => 'ro',
 	isa      => 'Str',
@@ -25,4 +18,7 @@ has style => (
 	isa      => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
