@@ -2,17 +2,10 @@ package FBP::MenuItem;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Object';
 
-
-
-
-
-######################################################################
-# Properties
-
 has id => (
 	is  => 'ro',
 	isa => 'Str',
@@ -63,13 +56,6 @@ has kind => (
 	isa => 'Str',
 );
 
-
-
-
-
-######################################################################
-# Events
-
 has OnMenuSelection => (
 	is  => 'ro',
 	isa => 'Str',
@@ -80,4 +66,7 @@ has OnUpdateUI => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
