@@ -2,8 +2,11 @@ package FBP::Panel;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Window';
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
