@@ -7,7 +7,7 @@ use Params::Util   ();
 use XML::SAX::Base ();
 use FBP            ();
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 our @ISA     = 'XML::SAX::Base';
 
 # Object XML class to Perl class mapping
@@ -18,6 +18,7 @@ my %OBJECT_CLASS = (
 	Panel                  => 'FBP::FormPanel',
 
 	# Direct Mappings
+	wxAnimationCtrl        => 'FBP::AnimationCtrl',
 	wxBitmapButton         => 'FBP::BitmapButton',
 	wxBoxSizer             => 'FBP::BoxSizer',
 	wxButton               => 'FBP::Button',
@@ -32,6 +33,7 @@ my %OBJECT_CLASS = (
 	wxFlexGridSizer        => 'FBP::FlexGridSizer',
 	wxFontPickerCtrl       => 'FBP::FontPickerCtrl',
 	wxGauge                => 'FBP::Gauge',
+	wxGridBagSizer         => 'FBP::GridBagSizer',
 	wxGridSizer            => 'FBP::GridSizer',
 	wxHtmlWindow           => 'FBP::HtmlWindow',
 	wxHyperlinkCtrl        => 'FBP::HyperLink',
@@ -41,8 +43,10 @@ my %OBJECT_CLASS = (
 	wxMenu                 => 'FBP::Menu',
 	wxMenuBar              => 'FBP::MenuBar',
 	wxMenuItem             => 'FBP::MenuItem',
+	wxNotebook             => 'FBP::Notebook',
 	wxPanel                => 'FBP::Panel',
 	wxRadioBox             => 'FBP::RadioBox',
+	wxRadioButton          => 'FBP::RadioButton',
 	wxScrolledWindow       => 'FBP::ScrolledWindow',
 	wxSearchCtrl           => 'FBP::SearchCtrl',
 	wxSlider               => 'FBP::Slider',
@@ -57,11 +61,14 @@ my %OBJECT_CLASS = (
 	wxTextCtrl             => 'FBP::TextCtrl',
 	wxToggleButton         => 'FBP::ToggleButton',
 	wxToolBar              => 'FBP::ToolBar',
+	wxTreeCtrl             => 'FBP::TreeCtrl',
 
 	# Special Mappings
-	submenu                => 'FBP::Menu',
+	gbsizeritem            => 'FBP::GridBagSizerItem',
 	listbookpage           => 'FBP::ListbookPage',
+	notebookpage           => 'FBP::NotebookPage',
 	sizeritem              => 'FBP::SizerItem',
+	submenu                => 'FBP::Menu',
 	separator              => 'FBP::MenuSeparator',
 	spacer                 => 'FBP::Spacer',
 	splitteritem           => 'FBP::SplitterItem',
