@@ -2,7 +2,7 @@ package FBP::RadioBox;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::ControlWithItems';
 
@@ -35,4 +35,7 @@ has OnRadioBox => (
 	isa      => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
