@@ -2,7 +2,7 @@ package FBP::ScrolledWindow;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Window';
 
@@ -16,4 +16,7 @@ has scroll_rate_y => (
 	isa => 'Int',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
