@@ -2,17 +2,10 @@ package FBP::SearchCtrl;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Control';
 
-
-
-
-
-######################################################################
-# Properties
-
 has value => (
 	is       => 'ro',
 	isa      => 'Str',
@@ -39,13 +32,6 @@ has cancel_button => (
 	default  => 0,
 );
 
-
-
-
-
-######################################################################
-# Events
-
 has OnText => (
 	is  => 'ro',
 	isa => 'Str',
@@ -66,4 +52,7 @@ has OnCancelButton => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
