@@ -2,7 +2,7 @@ package FBP::Sizer;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Object';
 with    'FBP::Children';
@@ -14,4 +14,7 @@ has name => (
 	required => 1,
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
