@@ -2,24 +2,18 @@ package FBP::SizerItem;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Object';
 with    'FBP::Children';
+with    'FBP::SizerItemBase';
 
 has proportion => (
 	is  => 'ro',
 	isa => 'Int',
 );
 
-has flag => (
-	is  => 'ro',
-	isa => 'Str',
-);
-
-has border => (
-	is  => 'ro',
-	isa => 'Int',
-);
+no Mouse;
+__PACKAGE__->meta->make_immutable;
 
 1;
