@@ -2,7 +2,7 @@ package FBP::Spacer;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Object';
 
@@ -16,4 +16,7 @@ has width => (
 	isa => 'Int',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
