@@ -2,7 +2,7 @@ package FBP::SplitterWindow;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Window';
 
@@ -61,4 +61,7 @@ has OnSplitterDClick => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
