@@ -3,7 +3,7 @@ package FBP::StaticBitmap;
 use Mouse;
 use Scalar::Util ();
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Window';
 
@@ -12,4 +12,7 @@ has bitmap => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
