@@ -2,7 +2,7 @@ package FBP::StaticBoxSizer;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::BoxSizer';
 
@@ -11,4 +11,7 @@ has label => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
