@@ -2,7 +2,7 @@ package FBP::StaticText;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Control';
 
@@ -17,4 +17,7 @@ has wrap => (
 	default  => '-1',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
