@@ -2,7 +2,7 @@ package FBP::StatusBar;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Window';
 
@@ -23,4 +23,7 @@ has style => (
 	isa      => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
