@@ -2,17 +2,10 @@ package FBP::StdDialogButtonSizer;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Sizer';
 
-
-
-
-
-######################################################################
-# Properties
-
 has OK => (
 	is  => 'ro',
 	isa => 'Bool',
@@ -53,13 +46,6 @@ has ContextHelp => (
 	isa => 'Bool',
 );
 
-
-
-
-
-######################################################################
-# Events
-
 has OnOKButtonClick => (
 	is  => 'ro',
 	isa => 'Str',
@@ -100,4 +86,7 @@ has OnContextHelpButtonClick => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
