@@ -2,17 +2,10 @@ package FBP::TextCtrl;
 
 use Mouse;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 extends 'FBP::Control';
 
-
-
-
-
-######################################################################
-# Properties
-
 has value => (
 	is       => 'ro',
 	isa      => 'Str',
@@ -32,13 +25,6 @@ has maxlength => (
 	default  => 0,
 );
 
-
-
-
-
-######################################################################
-# Events
-
 has OnText => (
 	is  => 'ro',
 	isa => 'Str',
@@ -59,4 +45,7 @@ has OnTextMaxLen => (
 	isa => 'Str',
 );
 
+no Mouse;
+__PACKAGE__->meta->make_immutable;
+
 1;
